==> owncloud-10.0.7.tgz: owncloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Malĝusta pasvorto",
    "Authentication error" : "Aŭtentiga eraro",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Motoro ne subtenas ŝanĝi pasvorton, sed la ĉifroŝlosilo de la uzanto sukcese ĝisdatiĝis.",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Saved" : "Konservita",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "__language_name__" : "Esperanto",
    "Language changed" : "La lingvo estas ŝanĝita",
    "Invalid request" : "Nevalida peto",
    "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
    "Unknown user" : "Nekonata uzanto",
    "All" : "Ĉio",
    "Enabled" : "Kapabligita",
    "Please wait...." : "Bonvolu atendi...",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updating...." : "Ĝisdatigata...",
    "Error while updating app" : "Eraris ĝisdatigo de la aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Uninstalling ...." : "Malinstalante...",
    "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
    "Uninstall" : "Malinstali",
    "Delete" : "Forigi",
    "Sending..." : "Sendante...",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "add group" : "aldoni grupon",
    "enabled" : "kapabligita",
    "disabled" : "malkapabligita",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "User documentation" : "Uzodokumentaro",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Uninstall App" : "Malinstali aplikaĵon",
    "Cron" : "Cron",
    "Open documentation" : "Malfermi la dokumentaron",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
    "Fatal issues only" : "Fatalaĵoj nur",
    "Log" : "Protokolo",
    "What to log" : "Kion protokoli",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite uziĝas kiel datumbazo. Por pli grandaj instaloj ni rekomendas ŝanĝi ĝin per malsama datumbazomotoro.",
    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
    "Desktop client" : "Labortabla kliento",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Password" : "Pasvorto",
    "Unable to change your password" : "Ne eblis ŝanĝi vian pasvorton",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Unlimited" : "Senlima",
    "Name" : "Nomo",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Version" : "Eldono",
    "Personal" : "Persona",
    "Admin" : "Administranto",
    "Error" : "Eraro",
    "Show last log in" : "Montri lastan ensaluton",
    "Show user backend" : "Montri uzantomotoron",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Add Group" : "Aldoni grupon",
    "Group" : "Grupo",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Default Quota" : "Defaŭlta kvoto",
    "Other" : "Alia",
    "Full Name" : "Plena nomo",
    "Group Admin for" : "Grupadministranto en",
    "Quota" : "Kvoto",
    "User Backend" : "Uzantomotoro",
    "Last Login" : "Lasta ensaluto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Malĝusta pasvorto",
    "Authentication error" : "Aŭtentiga eraro",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Motoro ne subtenas ŝanĝi pasvorton, sed la ĉifroŝlosilo de la uzanto sukcese ĝisdatiĝis.",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Saved" : "Konservita",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "__language_name__" : "Esperanto",
    "Language changed" : "La lingvo estas ŝanĝita",
    "Invalid request" : "Nevalida peto",
    "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
    "Unknown user" : "Nekonata uzanto",
    "All" : "Ĉio",
    "Enabled" : "Kapabligita",
    "Please wait...." : "Bonvolu atendi...",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updating...." : "Ĝisdatigata...",
    "Error while updating app" : "Eraris ĝisdatigo de la aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Uninstalling ...." : "Malinstalante...",
    "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
    "Uninstall" : "Malinstali",
    "Delete" : "Forigi",
    "Sending..." : "Sendante...",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "add group" : "aldoni grupon",
    "enabled" : "kapabligita",
    "disabled" : "malkapabligita",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "User documentation" : "Uzodokumentaro",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Uninstall App" : "Malinstali aplikaĵon",
    "Cron" : "Cron",
    "Open documentation" : "Malfermi la dokumentaron",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
    "Fatal issues only" : "Fatalaĵoj nur",
    "Log" : "Protokolo",
    "What to log" : "Kion protokoli",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite uziĝas kiel datumbazo. Por pli grandaj instaloj ni rekomendas ŝanĝi ĝin per malsama datumbazomotoro.",
    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
    "Desktop client" : "Labortabla kliento",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Password" : "Pasvorto",
    "Unable to change your password" : "Ne eblis ŝanĝi vian pasvorton",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Unlimited" : "Senlima",
    "Name" : "Nomo",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Version" : "Eldono",
    "Personal" : "Persona",
    "Admin" : "Administranto",
    "Error" : "Eraro",
    "Show last log in" : "Montri lastan ensaluton",
    "Show user backend" : "Montri uzantomotoron",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Add Group" : "Aldoni grupon",
    "Group" : "Grupo",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Default Quota" : "Defaŭlta kvoto",
    "Other" : "Alia",
    "Full Name" : "Plena nomo",
    "Group Admin for" : "Grupadministranto en",
    "Quota" : "Kvoto",
    "User Backend" : "Uzantomotoro",
    "Last Login" : "Lasta ensaluto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta",
    "Share" : "Kunhavigi",
    "Add" : "Aldoni"
},
"nplurals=2; plural=(n != 1);");
